@@ -264,8 +264,9 @@ def ensure_identifyer(i, quote=None):
     elif type(i) == str:
         name = i
     else:
-        raise TypeError("Identifyers must either be Identifyer "
-                        "instances or strings. (Maybe user .name?)")
+        raise TypeError(f"Identifyers must either be Identifyer "
+                        f"instances or strings not {type(i)}. "
+                        f"(Maybe user .name?)")
 
     return Identifyer(name, quote)
 
@@ -777,7 +778,8 @@ class insert(Command):
         as column names and expecting the following dicts to provide
         data for each column.
         """
-        return insert(relation, list(dicts[0].keys()), dicts)
+        columns = [ column(name) for name in dicts[0].keys() ]
+        return insert(relation, columns, dicts)
 
     def sql(self):
         relation = self._relation
